summaryrefslogtreecommitdiffstats
path: root/ipalib/errors2.py
diff options
context:
space:
mode:
authorJason Gerard DeRose <jderose@redhat.com>2009-01-30 20:53:32 -0700
committerRob Crittenden <rcritten@redhat.com>2009-02-03 15:29:05 -0500
commitc2b0c801400fcb59be8687f9faf061aa85bcffd2 (patch)
tree434634987f8888ad5b0b66db78627f9e37206c84 /ipalib/errors2.py
parent91ca06f079f4de1ca5e6c60cfdf7aae75f60821b (diff)
downloadfreeipa-c2b0c801400fcb59be8687f9faf061aa85bcffd2.tar.gz
freeipa-c2b0c801400fcb59be8687f9faf061aa85bcffd2.tar.xz
freeipa-c2b0c801400fcb59be8687f9faf061aa85bcffd2.zip
Started work on a much simplified mod_python server
Diffstat (limited to 'ipalib/errors2.py')
-rw-r--r--ipalib/errors2.py22
1 files changed, 19 insertions, 3 deletions
diff --git a/ipalib/errors2.py b/ipalib/errors2.py
index d1ece25d5..ebb1fdaf6 100644
--- a/ipalib/errors2.py
+++ b/ipalib/errors2.py
@@ -410,9 +410,26 @@ class KerberosError(AuthenticationError):
errno = 1100
+class CCacheError(KerberosError):
+ """
+ **1101** Raised when sever does not recieve Kerberose credentials.
+
+ For example:
+
+ >>> raise CCacheError()
+ Traceback (most recent call last):
+ ...
+ CCacheError: did not receive Kerberos credentials
+
+ """
+
+ errno = 1101
+ format = _('did not receive Kerberos credentials')
+
+
class ServiceError(KerberosError):
"""
**1101** Raised when service is not found in Kerberos DB.
For example:
@@ -420,10 +437,9 @@ class ServiceError(KerberosError):
Traceback (most recent call last):
...
ServiceError: Service 'HTTP@localhost' not found in Kerberos database
-
"""
- errno = 1101
+ errno = 1102
format = _('Service %(service)r not found in Kerberos database')
@@ -410,9 +410,26 @@ class KerberosError(AuthenticationError):
class ServiceError(KerberosError):
"""
- **1101** Raised when service is not found in Kerberos DB.
+ **1102** Raised when service is not found in Kerberos DB.
For example: